@@ -39,9 +39,10 @@ def _read_revision(vcs, uri):
 def _update(repository_uri, local_path, vcs):
     vcs_directory = os.path.join(local_path, vcs.directory_name)
     if not os.path.isdir(local_path):
-        raise RuntimeError("Checkout path already exists, and is not directory: " + local_path)
+        raise blah.errors.BlahUserError("Checkout path already exists, and is not directory: " + local_path)
     elif not os.path.isdir(vcs_directory):
-        raise RuntimeError("VCS directory doesn't exist: " + vcs_directory)
+        message = "{0} already exists and is not a git repository".format(local_path)
+        raise blah.errors.BlahUserError(message)
     else:
         local_repo = vcs.local_repo(local_path)
         current_remote_uri = local_repo.remote_repo_uri()
@@ -49,8 +50,7 @@ def _update(repository_uri, local_path, vcs):
             local_repo.update()
             return local_repo
         else:
-            raise RuntimeError(
-                "Checkout directory is checkout of different URI: " + current_remote_uri +
-                "\nExpected: " + repository_uri
-            )
+            message = "{0} is existing checkout of different repository: {1}" \
+                .format(local_path, current_remote_uri)
+            raise blah.errors.BlahUserError(message)
     
